@@ -82,14 +82,6 @@ class CheckboxesSampleForm(forms.Form):
     )
 
 
-class SelectSampleForm(forms.Form):
-    select = forms.ChoiceField(
-        choices=((1, "Option one"), (2, "Option two"), (3, "Option three")),
-        initial=(1,),
-        widget=forms.Select,
-    )
-
-
 class CrispyTestModel(models.Model):
     email = models.CharField(max_length=20)
     password = models.CharField(max_length=20)
@@ -111,8 +103,9 @@ class SampleForm4(forms.ModelForm):
         """
         before Django1.6, one cannot use __all__ shortcut for fields
         without getting the following error:
-        django.core.exceptions.FieldError: Unknown field(s) (a, l, _) specified
-        for CrispyTestModel because obviously it casts the string to a set
+        django.core.exceptions.FieldError: Unknown field(s) (a, l, _)
+        specified for CrispyTestModel because obviously it casts the
+        string to a set
         """
 
         model = CrispyTestModel
@@ -219,39 +212,29 @@ class FileForm(forms.Form):
     )
 
 
-class AdvancedFileForm(forms.Form):
-    file_field = forms.FileField(
-        widget=forms.FileInput(attrs={"class": "my-custom-class"})
-    )
-    clearable_file = forms.FileField(
-        widget=forms.ClearableFileInput(attrs={"class": "my-custom-class"}),
-        required=False,
-        initial=FakeFieldFile(),
-    )
+class FileFormRequired(forms.Form):
+    file_field = forms.FileField(required=True, widget=forms.FileInput)
+    clearable_file = forms.FileField(required=True, widget=forms.ClearableFileInput)
 
 
-class GroupedChoiceForm(forms.Form):
-    choices = [
-        (
-            "Audio",
-            [
-                ("vinyl", "Vinyl"),
-                ("cd", "CD"),
-            ],
-        ),
-        (
-            "Video",
-            [
-                ("vhs", "VHS Tape"),
-                ("dvd", "DVD"),
-            ],
-        ),
-        ("unknown", "Unknown"),
-    ]
-    checkbox_select_multiple = forms.MultipleChoiceField(
-        widget=forms.CheckboxSelectMultiple, choices=choices
+class InputsForm(forms.Form):
+    choices = ((1, "Option one"), (2, "Option two"), (3, "Option three"))
+    text_input = forms.CharField()
+    text_area = forms.CharField(widget=forms.Textarea())
+    checkboxes = forms.MultipleChoiceField(
+        choices=choices,
+        initial=(1,),
+        widget=forms.CheckboxSelectMultiple,
     )
-    radio = forms.MultipleChoiceField(widget=forms.RadioSelect, choices=choices)
+    radio = forms.ChoiceField(widget=forms.RadioSelect, choices=choices)
+    single_checkbox = forms.CharField(
+        label="company", required=False, widget=forms.CheckboxInput()
+    )
+    select_input = forms.ChoiceField(choices=choices)
+
+
+class LabelForm(forms.Form):
+    text_input = forms.CharField(label="Test html escape <>&")
 
 
 class CustomRadioSelect(forms.RadioSelect):
@@ -277,3 +260,38 @@ class SampleFormCustomWidgets(forms.Form):
         initial=(1,),
         widget=CustomCheckboxSelectMultiple,
     )
+
+
+class GroupedChoiceForm(forms.Form):
+    choices = [
+        (
+            "Audio",
+            [
+                ("vinyl", "Vinyl"),
+                ("cd", "CD"),
+            ],
+        ),
+        (
+            "Video",
+            [
+                ("vhs", "VHS Tape"),
+                ("dvd", "DVD"),
+            ],
+        ),
+        ("unknown", "Unknown"),
+    ]
+    checkbox_select_multiple = forms.MultipleChoiceField(
+        widget=forms.CheckboxSelectMultiple,
+        choices=choices,
+        help_text="help",
+    )
+    radio = forms.MultipleChoiceField(widget=forms.RadioSelect, choices=choices)
+
+
+class HelpTextForm(forms.Form):
+    email = forms.EmailField(
+        label="email",
+        required=True,
+        widget=forms.TextInput(),
+        help_text="Insert your <b>email</b>",
+    )
