@@ -1,3 +1,4 @@
+import django
 import pytest
 from crispy_forms.bootstrap import (
     AppendedText,
@@ -16,6 +17,7 @@ from django.forms.models import formset_factory, modelformset_factory
 from django.middleware.csrf import _get_new_csrf_string
 from django.shortcuts import render
 from django.template import Context, Template
+from django.test import override_settings
 from django.urls import reverse
 from django.utils.translation import gettext_lazy as _
 
@@ -36,6 +38,12 @@ from .forms import (
 )
 from .utils import contains_partial, parse_expected, parse_form
 
+CONVERTERS = {
+    "textinput": "inputtext textinput textInput",
+    "fileinput": "fileinput fileUpload",
+    "passwordinput": "textinput textInput",
+}
+
 
 def test_invalid_unicode_characters(settings):
     # Adds a BooleanField that uses non valid unicode characters "ñ"
@@ -314,8 +322,11 @@ def test_bs5_field_with_buttons_css_classes():
             ),
         )
     )
-
-    assert parse_form(form) == parse_expected("field_with_buttons.html")
+    if django.VERSION < (5, 0):
+        expected = "field_with_buttons_lt50.html"
+    else:
+        expected = "field_with_buttons.html"
+    assert parse_form(form) == parse_expected(expected)
 
     form = SampleForm3({})
     form.helper = FormHelper()
@@ -328,9 +339,14 @@ def test_bs5_field_with_buttons_css_classes():
             ),
         )
     )
-    assert parse_form(form) == parse_expected("field_with_buttons_failing.html")
+    if django.VERSION < (5, 0):
+        expected = "field_with_buttons_failing_lt50.html"
+    else:
+        expected = "field_with_buttons_failing.html"
+    assert parse_form(form) == parse_expected(expected)
 
 
+@override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
 def test_formset_layout():
     SampleFormSet = formset_factory(SampleForm, extra=3)
     formset = SampleFormSet()
@@ -523,6 +539,7 @@ def test_keepcontext_context_manager():
     assert response.content.count(b"form-check-input") > 0
 
 
+@override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
 def test_bootstrap5_form_inline():
     form = SampleForm()
     form.helper = FormHelper()
@@ -530,7 +547,11 @@ def test_bootstrap5_form_inline():
     form.helper.field_template = "bootstrap5/layout/inline_field.html"
     form.helper.layout = Layout("email", "password1", "last_name")
     form.helper.form_class = "row row-cols-lg-auto"
-    assert parse_form(form) == parse_expected("test_bootstrap5_form_inline.html")
+    if django.VERSION < (5, 0):
+        expected = "test_bootstrap5_form_inline_lt50.html"
+    else:
+        expected = "test_bootstrap5_form_inline.html"
+    assert parse_form(form) == parse_expected(expected)
 
 
 def test_select():
@@ -557,7 +578,7 @@ def test_update_attributes_class():
     form.helper.layout = Layout("email", Field("password1"), "password2")
     form.helper["password1"].update_attributes(css_class="hello")
     html = render_crispy_form(form)
-    assert html.count(' class="hello textinput') == 1
+    assert html.count(' class="hello') == 1
     form.helper = FormHelper()
     form.helper.layout = Layout(
         "email",
@@ -566,7 +587,7 @@ def test_update_attributes_class():
     )
     form.helper["password1"].update_attributes(css_class="hello2")
     html = render_crispy_form(form)
-    assert html.count(' class="hello hello2 textinput') == 1
+    assert html.count(' class="hello hello2') == 1
 
 
 def test_file_field():
@@ -584,11 +605,19 @@ def test_file_field():
     form.helper = FormHelper()
     form.helper.layout = Layout("clearable_file")
 
-    assert parse_form(form) == parse_expected("test_clearable_file_field_failing.html")
+    if django.VERSION < (5, 0):
+        expected = "test_clearable_file_field_failing_lt50.html"
+    else:
+        expected = "test_clearable_file_field_failing.html"
+    assert parse_form(form) == parse_expected(expected)
 
     form.helper.layout = Layout("file_field")
 
-    assert parse_form(form) == parse_expected("test_file_field_failing.html")
+    if django.VERSION < (5, 0):
+        expected = "test_file_field_failing_lt50.html"
+    else:
+        expected = "test_file_field_failing.html"
+    assert parse_form(form) == parse_expected(expected)
 
 
 def test_row():
@@ -611,12 +640,17 @@ def test_html_label_escape():
     assert "&lt;&gt;&amp;" in html
 
 
+@override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
 def test_tabular_formset_layout():
     SampleFormSet = formset_factory(SampleForm, extra=3)
     formset = SampleFormSet()
     formset.helper = FormHelper()
     formset.helper.template = "bootstrap5/table_inline_formset.html"
-    assert parse_form(formset) == parse_expected("test_tabular_formset_layout.html")
+    if django.VERSION < (5, 0):
+        expected = "test_tabular_formset_layout_lt50.html"
+    else:
+        expected = "test_tabular_formset_layout.html"
+    assert parse_form(formset) == parse_expected(expected)
 
     SampleFormSet = formset_factory(SampleForm, extra=3)
     data = {
@@ -626,9 +660,11 @@ def test_tabular_formset_layout():
     formset = SampleFormSet(data)
     formset.helper = FormHelper()
     formset.helper.template = "bootstrap5/table_inline_formset.html"
-    assert parse_form(formset) == parse_expected(
-        "test_tabular_formset_layout_failing.html"
-    )
+    if django.VERSION < (5, 0):
+        expected = "test_tabular_formset_layout_failing_lt50.html"
+    else:
+        expected = "test_tabular_formset_layout_failing.html"
+    assert parse_form(formset) == parse_expected(expected)
 
 
 def test_flat_attrs_safe():
@@ -647,4 +683,8 @@ def test_help_text_no_escape():
     form = HelpTextForm()
     form.helper = FormHelper()
     form.helper.form_tag = False
-    assert parse_form(form) == parse_expected("help_text_escape.html")
+    if django.VERSION < (5, 0):
+        expected = "help_text_escape_lt50.html"
+    else:
+        expected = "help_text_escape.html"
+    assert parse_form(form) == parse_expected(expected)
