@@ -1,5 +1,6 @@
 import random
 
+import django
 import pytest
 from crispy_forms.bootstrap import (
     Accordion,
@@ -21,6 +22,7 @@ from crispy_forms.layout import HTML, Field, Layout, MultiWidgetField
 from crispy_forms.utils import render_crispy_form
 from django import forms
 from django.template import Context, Template
+from django.test import override_settings
 from django.utils.translation import activate, deactivate
 from django.utils.translation import gettext as _
 
@@ -37,6 +39,12 @@ from .forms import (
 )
 from .utils import parse_expected, parse_form
 
+CONVERTERS = {
+    "textinput": "inputtext textinput textInput",
+    "fileinput": "fileinput fileUpload",
+    "passwordinput": "textinput textInput",
+}
+
 
 def test_field_with_custom_template():
     test_form = SampleForm()
@@ -202,6 +210,7 @@ class TestBootstrapLayoutObjects:
         html = render_crispy_form(form)
         assert 'class="form-check-input"' in html
 
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_prepended_appended_text(self):
         test_form = SampleForm()
         test_form.helper = FormHelper()
@@ -212,9 +221,11 @@ class TestBootstrapLayoutObjects:
             AppendedText("password1", "#"),
             PrependedText("password2", "$"),
         )
-        assert parse_form(test_form) == parse_expected(
-            "test_prepended_appended_text.html"
-        )
+        if django.VERSION < (5, 0):
+            expected = "test_prepended_appended_text_lt50.html"
+        else:
+            expected = "test_prepended_appended_text.html"
+        assert parse_form(test_form) == parse_expected(expected)
 
     def test_inline_radios(self):
         test_form = CheckboxesSampleForm()
@@ -223,6 +234,7 @@ class TestBootstrapLayoutObjects:
         html = render_crispy_form(test_form)
         assert html.count('form-check-inline"') == 2
 
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_accordion_and_accordiongroup(self):
         random.seed(0)
         form = SampleForm()
@@ -269,6 +281,7 @@ class TestBootstrapLayoutObjects:
             == 0
         )
 
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_bs5accordion(self):
         random.seed(0)
         form = SampleForm()
@@ -315,6 +328,7 @@ class TestBootstrapLayoutObjects:
             == 0
         )
 
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_bs5accordion_flush(self):
         random.seed(0)
         test_form = SampleForm()
@@ -329,6 +343,7 @@ class TestBootstrapLayoutObjects:
         )
         assert parse_form(test_form) == parse_expected("accordion_flush.html")
 
+    @override_settings(CRISPY_CLASS_CONVERTERS=CONVERTERS)
     def test_bs5accordion_always_open(self):
         random.seed(0)
         test_form = SampleForm()
@@ -535,7 +550,11 @@ class TestBootstrapLayoutObjects:
             FloatingField("text_area"),
             FloatingField("select_input"),
         )
-        assert parse_form(form) == parse_expected("test_floating_field_failing.html")
+        if django.VERSION < (5, 0):
+            expected = "test_floating_field_failing_lt50.html"
+        else:
+            expected = "test_floating_field_failing.html"
+        assert parse_form(form) == parse_expected(expected)
 
     def test_grouped_checkboxes_radios(self):
         form = GroupedChoiceForm()
@@ -548,8 +567,15 @@ class TestBootstrapLayoutObjects:
         form = GroupedChoiceForm({})
         form.helper = FormHelper()
         form.helper.layout = Layout("checkbox_select_multiple")
-        assert parse_form(form) == parse_expected(
-            "test_grouped_checkboxes_failing.html"
-        )
+        if django.VERSION < (5, 0):
+            expected = "test_grouped_checkboxes_failing_lt50.html"
+        else:
+            expected = "test_grouped_checkboxes_failing.html"
+        assert parse_form(form) == parse_expected(expected)
+
         form.helper.layout = Layout("radio")
-        assert parse_form(form) == parse_expected("test_grouped_radios_failing.html")
+        if django.VERSION < (5, 0):
+            expected = "test_grouped_radios_failing_lt50.html"
+        else:
+            expected = "test_grouped_radios_failing.html"
+        assert parse_form(form) == parse_expected(expected)
