@@ -1,3 +1,4 @@
+import django
 import pytest
 from crispy_forms.exceptions import CrispyError
 from crispy_forms.templatetags.crispy_forms_field import crispy_addon
@@ -93,7 +94,10 @@ def test_as_crispy_errors_formset_with_non_form_errors():
     c = Context({"formset": formset})
     html = template.render(c)
     assert "errorMsg" in html or "alert" in html
-    assert "<li>Please submit at most 1 form.</li>" in html
+    if django.VERSION < (3, 2):
+        assert "<li>Please submit 1 or fewer forms.</li>" in html
+    else:
+        assert "<li>Please submit at most 1 form.</li>" in html
     assert "<h3>" not in html
 
 
